package com.ycwl.basic.biz;

import com.ycwl.basic.mapper.SourceMapper;
import com.ycwl.basic.model.pc.face.entity.FaceEntity;
import com.ycwl.basic.model.pc.face.resp.FaceRespVO;
import com.ycwl.basic.model.pc.faceSample.entity.FaceSampleEntity;
import com.ycwl.basic.model.pc.faceSample.resp.FaceSampleRespVO;
import com.ycwl.basic.model.pc.source.entity.SourceEntity;
import com.ycwl.basic.model.pc.template.entity.TemplateConfigEntity;
import com.ycwl.basic.repository.FaceRepository;
import com.ycwl.basic.repository.SourceRepository;
import com.ycwl.basic.repository.TemplateRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Collectors;

@Component
public class TemplateBiz {
    @Autowired
    private TemplateRepository templateRepository;
    @Autowired
    private FaceRepository faceRepository;
    @Autowired
    private SourceMapper sourceMapper;
    @Autowired
    private SourceRepository sourceRepository;


    public boolean determineTemplateCanGenerate(Long templateId, Long faceId) {
        List<String> placeholderList = templateRepository.getTemplatePlaceholder(templateId);
        TemplateConfigEntity templateConfig = templateRepository.getTemplateConfig(templateId);
        int minimalPlaceholderFill = 1;
        if (null != templateConfig) {
            if (null != templateConfig.getMinimalPlaceholderFill()) {
                minimalPlaceholderFill = templateConfig.getMinimalPlaceholderFill();
            }
        }
        if (minimalPlaceholderFill <= 0) {
            return true;
        }
        FaceEntity face = faceRepository.getFace(faceId);
        List<FaceSampleEntity> faceSampleList = faceRepository.getFaceSampleList(faceId);
        if (faceSampleList.isEmpty()) {
            return false;
        }
        List<SourceEntity> sourceEntities = sourceMapper.listVideoByScenicFaceRelation(face.getScenicId(), faceId);
        long count = sourceEntities.stream().map(SourceEntity::getDeviceId).filter(deviceId -> placeholderList.contains(deviceId.toString())).count();
        return count >= minimalPlaceholderFill;
    }

}
